<?php

namespace Drupal\syncart\Hook;

use Drupal\taxonomy\Entity\Term;

/**
 * Hook preprocess page class.
 */
class PreprocessCommerceProduct {

  /**
   * Hook.
   */
  public static function hook(&$variables) {
    $variables['cart'] = [
      '#theme' => 'syncart-cart-field',
      '#data' => self::getProductVariation($variables['product_entity'], $variables['elements']['#view_mode']),
    ];

    $variables['favorite'] = [
      '#theme' => 'syncart-favorite-field',
      '#data' => [
        'uid' => \Drupal::currentUser()->id(),
        'product' => $variables['product_entity'],
      ],
    ];
  }

  /**
   * Get product variation price.
   */
  public static function getProductVariation($product, $view_mode) {
    $full = $view_mode == 'full' ? TRUE : FALSE;
    $unit_name = '';
    $qfloat = 0;
    $qstep = 1;
    if ($product->hasField('field_unit')) {
      $unit = $product->get('field_unit')->getValue();
      if (!empty($unit)) {
        $term = Term::load($unit[0]['target_id']);
        $unit_name = $term->getName();
        $qfloat = (int) $term->get('field_unit_float')->getValue()[0]['value'];
        if ($qfloat != 0) {
          $config = \Drupal::config('core.entity_form_display.commerce_order_item.default.default');
          $qstep = round($config->getRawData()['content']['quantity']['settings']['step'], 2);
        }
      }
    }
    $result = FALSE;
    $conf = \Drupal::config('core.entity_view_display.commerce_product_variation.variation.default');
    $variation_definitions = $conf->getRawData()['content'];
    $attribute_original = \Drupal::entityTypeManager()
      ->getStorage('commerce_product_attribute')
      ->getQuery()
      ->execute();
    $attribute_weight = [];
    $weight = 100;
    foreach ($attribute_original as $key => $value) {
      if (array_key_exists("attribute_{$key}", $variation_definitions)) {
        $attribute_weight[$key] = $variation_definitions["attribute_{$key}"]['weight'];
      }
      else {
        if ($key == 'color') {
          $attribute_weight[$key] = 1;
        }
        else {
          $attribute_weight[$key] = $weight++;
        }
      }
    }
    $config = \Drupal::config('syncart.settings');
    $check_store = (bool) $config->get('check_store');
    if (is_null($check_store)) {
      $check_store = FALSE;
    }
    $novariation = $config->get('no_variation_text');
    if (is_null($novariation)) {
      $novariation = '';
    }
    $showquantity = $config->get('show_quantity');
    if (is_null($showquantity)) {
      $showquantity = 0;
    }
    $currency_storage = \Drupal::entityTypeManager()->getStorage('commerce_currency');
    $currency_formatter = \Drupal::service('commerce_price.currency_formatter');
    $prices = [];
    $attributes = [];
    foreach ($product->variations as $item) {
      $variation = $item->entity;
      if (!is_object($variation->field_stock)) {
        $stock = 0;
      }
      else {
        $stock = (int) $variation->field_stock->value;
      }
      if (!is_object($variation)) {
        continue;
      }
      $priceObject = $variation->getPrice();
      if (!is_object($priceObject)) {
        continue;
      }
      $attribute_item = [];
      $weight = 1;
      foreach ($variation->getAttributeValues() as $key => $value) {
        $attribute_label = $value->getAttribute()->label();
        $attribute_original = $value->getAttribute()->getOriginalId();
        $attribute_item[] = [
          'id' => $value->id(),
          'label' => $attribute_label,
          'name' => $value->getName(),
        ];
        if ($check_store && $stock == 0) {
          continue;
        }
        $attribute = [
          'id' => $value->id(),
          'name' => $value->getName(),
        ];
        if (empty($attributes)) {
          $attributes[$attribute_weight[$attribute_original]][$attribute_label][] = $attribute;
        }
        if (empty($attributes[$attribute_weight[$attribute_original]][$attribute_label])) {
          $attributes[$attribute_weight[$attribute_original]][$attribute_label][] = $attribute;
        }
        elseif (!in_array($attribute, $attributes[$attribute_weight[$attribute_original]][$attribute_label])) {
          $attributes[$attribute_weight[$attribute_original]][$attribute_label][] = $attribute;
        }
      }
      $price = $priceObject->getNumber();
      $currency_code = $variation->getPrice()->getCurrencyCode();
      /** @var \Drupal\commerce_price\Entity\CurrencyInterface $currency */
      $currency = $currency_storage->load($currency_code);
      $old_price = FALSE;
      if ($variation->field_oldprice && $variation->field_oldprice->value) {
        $old_price = $variation->field_oldprice->value;
      }

      $prices[] = [
        'variation_id' => $variation->id(),
        'price' => $price,
        'old_price' => $old_price,
        'currency_code' => $currency_code,
        'price_format' => !empty($price) ? $currency_formatter->format($price, $currency_code, []) : '',
        'oldprice_format' => !empty($old_price) ? $currency_formatter->format($old_price, $currency_code, []) : '',
        'currency' => $currency->getSymbol(),
        'attributes' => $attribute_item,
        'stock' => $stock,
      ];
      // if (!$full) {
      //   break;
      // }
    }
    ksort($attributes);
    $attributes_sorted = [];
    $first = TRUE;
    $master = [];
    foreach ($attributes as $sorted) {
      foreach ($sorted as $key => $value) {
        if ($first) {
          foreach ($value as $id) {
            $master[] = $id['id'];
          }
        }
        $attributes_sorted[$key] = $value;
      }
      $first = FALSE;
    }
    $result = [
      'product' => $product,
      'settings' => [
        'unit' => $unit_name,
        'qstep' => $qstep,
        'fullstate' => $full,
        'checkstore' => $check_store,
        'showquantity' => $showquantity,
        'novariation' => $novariation,
        'masterarray' => $master,
      ],
      'prices' => $prices,
      'attributes' => $attributes_sorted,
      'uid' => \Drupal::currentUser()->id(),
    ];
    return $result;
  }

}
